@@ -894,6 +894,23 @@ public final class WorkspaceStorageHubClientService implements Workspace{
 	}
 
 
+	/* (non-Javadoc)
+	 * @see org.gcube.common.storagehubwrapper.server.tohl.Workspace#getMetadata(java.lang.String)
+	 */
+	@Override
+	public Map<String, Object> getMetadata(String itemId) throws Exception {
+
+		try{
+
+			return storageHubClientService.getMetadata(itemId);
+
+		}catch(Exception e){
+			logger.error("Error on getting Metadata for: "+itemId, e);
+			throw new Exception("Error on getting Metadata for: "+itemId);
+		}
+	}
+
+
 
 
 
